@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::Direct;
-$Search::Elasticsearch::Client::Direct::VERSION = '1.16';
+$Search::Elasticsearch::Client::Direct::VERSION = '1.17';
 use Moo;
 with 'Search::Elasticsearch::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -118,7 +118,7 @@ Search::Elasticsearch::Client::Direct - Thin client with full support for Elasti
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -589,17 +589,17 @@ Query string parameters:
 See the L<update docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-update.html>
 for more information.
 
-=head2 C<termvector()>
+=head2 C<termvectors()>
 
-    $results = $e->termvector(
+    $results = $e->termvectors(
         index   => $index,          # required
         type    => $type,           # required
-        id      => $id,             # required
 
+        id      => $id,             # optional
         body    => {...}            # optional
     )
 
-The C<termvector()> method retrieves term and field statistics, positions,
+The C<termvectors()> method retrieves term and field statistics, positions,
 offsets and payloads for the specified document, assuming that termvectors
 have been enabled.
 
@@ -614,7 +614,9 @@ Query string parameters:
     C<preference>,
     C<realtime>,
     C<routing>,
-    C<term_statistics>
+    C<term_statistics>,
+    C<version>,
+    C<version_type>
 
 See the L<termvector docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-termvectors.html>
 for more information.
@@ -835,7 +837,9 @@ Query string parameters:
     C<preference>,
     C<realtime>,
     C<routing>,
-    C<term_statistics>
+    C<term_statistics>,
+    C<version>,
+    C<version_type>
 
 See the L<mtermvectors docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/docs-multi-termvectors.html>
 for more information.
@@ -912,6 +916,7 @@ Query string parameters:
     C<suggest_mode>,
     C<suggest_size>,
     C<suggest_text>,
+    C<terminate_after>,
     C<timeout>,
     C<track_scores>,
     C<version>
